use 5.006;
use strict;
use warnings;

package Win32::App::which;
BEGIN {
    $Win32::App::which::VERSION = '1.021';
}

1;
__END__

=head1 NAME

Win32::App::which - The 'which' Unix classic command for Windows

=head1 SYNOPSIS

See L<which>.

=head1 AUTHOR

Olivier MenguE<eacute> C<<dolmen@cpan.org>>.

=head1 COPYRIGHT & LICENSE

Copyright E<copy> 2010-2011 Olivier MenguE<eacute>.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see L<http://www.gnu.org/licenses/>.

=cut
